# remirepo/fedora spec file for php-pecl-rdkafka6
#
# Copyright (c) 2015-2024 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

# use library installed in /opt, change to use system library
%bcond_without     move_to_opt

# run test suite, change to skip it
%bcond_without     tests

%if 0%{?scl:1}
%scl_package       php-pecl-rdkafka6
%endif

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  rdkafka
%global ini_name   40-%{pecl_name}.ini

%if %{with move_to_opt}
# Disable RPATH check
%global __arch_install_post /bin/true
%global __brp_check_rpaths  /bin/true

%global buildver %(PKG_CONFIG_PATH=/opt/%{?vendeur:%{vendeur}/}librdkafka/%{_lib}/pkgconfig pkg-config --silence-errors --modversion rdkafka 2>/dev/null || echo 65536)
%else
%global buildver %(pkg-config --silence-errors --modversion rdkafka 2>/dev/null || echo 65536)
%endif

%global upstream_version 6.0.4
#global upstream_prever  RC2
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

Summary:        Kafka client based on librdkafka
Name:           %{?scl_prefix}php-pecl-%{pecl_name}6
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        MIT
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

# See https://github.com/arnaud-lb/php-rdkafka/issues/562
Patch0:         upstream.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
%if %{with move_to_opt}
BuildRequires:  %{?vendeur:%{vendeur}-}librdkafka-devel   >= 2.2
Requires:       %{?vendeur:%{vendeur}-}librdkafka%{?_isa} >= %{buildver}
%else
BuildRequires:  librdkafka-devel >= 1.4
%endif
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}

%if 0%{?fedora} >= 36 || 0%{?rhel} >= 9 || "%{php_version}" >= "8.1"
Obsoletes:     %{?scl_prefix}php-pecl-%{pecl_name}          < 5
Obsoletes:     %{?scl_prefix}php-pecl-%{pecl_name}5         < 6
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%else
# A single version can be installed
Conflicts:     %{?scl_prefix}php-pecl-%{pecl_name}          < 5
Conflicts:     %{?scl_prefix}php-pecl-%{pecl_name}5         < 6
%endif
# no BC break (only PHP supported versions)
Obsoletes:     %{?scl_prefix}php-pecl-%{pecl_name}4         < 5
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}4         = %{version}-%{release}
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}4%{?_isa} = %{version}-%{release}

%if %{with move_to_opt}
%global __requires_exclude_from ^%{_libdir}/.*$
%endif


%description
This extension is a librdkafka binding providing a working client for Kafka.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
%patch -P0 -p1 -b .up

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_RDKAFKA_VERSION/{s/.* "//;s/".*$//;p}' php_rdkafka.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
mkdir ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

%if %{with move_to_opt}
# not yet used
export PKG_CONFIG_PATH=/opt/%{?vendeur:%{vendeur}/}librdkafka/%{_lib}/pkgconfig
%endif

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
    --with-php-config=%{__phpconfig} \
    --with-libdir=%{_lib} \
%if %{with move_to_opt}
    --with-rdkafka=/opt/%{?vendeur:%{vendeur}/}librdkafka
%else
     --with-rdkafka
%endif

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --with-php-config=%{__ztsphpconfig} \
    --with-libdir=%{_lib} \
%if %{with move_to_opt}
    --with-rdkafka=/opt/%{?vendeur:%{vendeur}/}librdkafka
%else
     --with-rdkafka
%endif

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif

%if %{with tests}
: Upstream test suite  for NTS extension
cd %{sources}
TEST_PHP_ARGS="-n -d extension=$PWD/../NTS/modules/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -P -q --show-diff
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Fri Oct 25 2024 Remi Collet <remi@remirepo.net> - 6.0.4-2
- add upstream patch for old PHP versions

* Fri Oct 25 2024 Remi Collet <remi@remirepo.net> - 6.0.4-1
- update to 6.0.4
- open https://github.com/arnaud-lb/php-rdkafka/issues/562
  build broken with PHP 7.2 and older

* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 6.0.3-4
- rebuild for PHP 8.3.0RC1

* Wed Jul 12 2023 Remi Collet <remi@remirepo.net> - 6.0.3-3
- build out of sources tree

* Thu Jan 19 2023 Remi Collet <remi@remirepo.net> - 6.0.3-2
- rebuild using remi-librdkafka 2.0.1

* Mon Jul  4 2022 Remi Collet <remi@remirepo.net> - 6.0.3-1
- update to 6.0.3 (no change)
- rebuild with librdkafka 1.9.0

* Mon Jun 13 2022 Remi Collet <remi@remirepo.net> - 6.0.2-1
- update to 6.0.2

* Tue Feb 15 2022 Remi Collet <remi@remirepo.net> - 6.0.1-1
- update to 6.0.1

* Fri Jan  7 2022 Remi Collet <remi@remirepo.net> - 6.0.0-1
- update to 6.0.0

* Sun Nov 28 2021 Remi Collet <remi@remirepo.net> - 6.0.0~RC2-1
- update to 6.0.0RC2
- drop patch merged upstream

* Sat Nov 20 2021 Remi Collet <remi@remirepo.net> - 6.0.0~RC1-1
- update to 6.0.0RC1
- rename to php-pecl-rdkafka6
- fix segfault using patch from
  https://github.com/arnaud-lb/php-rdkafka/pull/492
- open https://github.com/arnaud-lb/php-rdkafka/issues/493
  discussion about nullable vs optional

* Fri Nov 19 2021 Remi Collet <remi@remirepo.net> - 5.0.1-1
- update to 5.0.1

* Fri Nov 19 2021 Remi Collet <remi@remirepo.net> - 5.0.1-1
- update to 5.0.1
- drop patch merged upstream

* Fri Sep 10 2021 Remi Collet <remi@remirepo.net> - 5.0.0-4
- run upstream test suite during the build
  (lot of tests are skipped as no configured server)

* Fri Sep 10 2021 Remi Collet <remi@remirepo.net> - 5.0.0-3
- add fix for PHP 8.1 from upstream and from
  https://github.com/arnaud-lb/php-rdkafka/pull/467

* Wed Jan 27 2021 Remi Collet <remi@remirepo.net> - 5.0.0-2
- rebuild with librdkafka version 1.6.0

* Thu Jan 14 2021 Remi Collet <remi@remirepo.net> - 5.0.0-1
- update to 5.0.0
- rename to php-pecl-rdkafka5

* Fri Dec 25 2020 Remi Collet <remi@remirepo.net> - 4.1.2-1
- update to 4.1.2

* Tue Dec  8 2020 Remi Collet <remi@remirepo.net> - 4.1.1-1
- update to 4.1.1

* Mon Dec  7 2020 Remi Collet <remi@remirepo.net> - 4.1.0-2
- add upstream patches for PHP 8

* Mon Dec  7 2020 Remi Collet <remi@remirepo.net> - 4.1.0-1
- update to 4.1.0

* Thu Oct  8 2020 Remi Collet <remi@remirepo.net> - 4.0.4-1
- update to 4.0.4

* Sun Jun 21 2020 Remi Collet <remi@remirepo.net> - 4.0.3-2
- rebuild using librdkafka1php 1.4.4

* Fri Feb  7 2020 Remi Collet <remi@remirepo.net> - 4.0.3-1
- update to 4.0.3

* Mon Dec 16 2019 Remi Collet <remi@remirepo.net> - 4.0.2-1
- update to 4.0.2

* Mon Dec  9 2019 Remi Collet <remi@remirepo.net> - 4.0.1-1
- update to 4.0.1

* Sat Oct  5 2019 Remi Collet <remi@remirepo.net> - 4.0.0-1
- update to 4.0.0
- rename to php-pecl-rdkafka4
- raise dependency on librdkafka 0.11

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 3.1.2-2
- rebuild for 7.4.0RC1

* Tue Jul  9 2019 Remi Collet <remi@remirepo.net> - 3.1.2-1
- update to 3.1.2

* Mon Jul  8 2019 Remi Collet <remi@remirepo.net> - 3.1.1-2
- add upstream patch to fix PHP 5.6 build

* Wed Jul  3 2019 Remi Collet <remi@remirepo.net> - 3.1.1-1
- update to 3.1.1
- open https://github.com/arnaud-lb/php-rdkafka/issues/235
  broken build with PHP 5.6 (ZVAL_DEREF)

* Tue Jun 25 2019 Remi Collet <remi@remirepo.net> - 3.1.0-2
- rebuild with librdkafka 0.11 in EL-8

* Thu Apr 18 2019 Remi Collet <remi@remirepo.net> - 3.1.0-1
- update to 3.1.0
- raise dependency on PHP 5.6

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 3.0.5-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 3.0.5-2
- rebuild for 7.3.0alpha4 new ABI

* Mon Nov 20 2017 Remi Collet <remi@remirepo.net> - 3.0.5-1
- Update to 3.0.5

* Wed Aug 23 2017 Remi Collet <remi@remirepo.net> - 3.0.4-2
- EL-7 rebuild using librdkafka in EPEL

* Wed Aug 16 2017 Remi Collet <remi@remirepo.net> - 3.0.4-1
- Update to 3.0.4

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 3.0.3-4
- rebuild for PHP 7.2.0beta1 new API

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 3.0.3-2
- rebuild for 7.2.0alpha2

* Mon May 29 2017 Remi Collet <remi@remirepo.net> - 3.0.3-1
- Update to 3.0.3

* Wed May 24 2017 Remi Collet <remi@remirepo.net> - 3.0.2-1
- Update to 3.0.2 (stable)

* Sat Jan 28 2017 Remi Collet <remi@fedoraproject.org> - 3.0.1-1
- Update to 3.0.1

* Mon Dec 19 2016 Remi Collet <remi@fedoraproject.org> - 3.0.0-1
- update to 3.0.0 (php 5 and 7, stable)
- open https://github.com/arnaud-lb/php-rdkafka/issues/98 failed build
  fixed by https://github.com/arnaud-lb/php-rdkafka/pull/99

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-2
- rebuild with PHP 7.1.0 GA

* Mon Nov 28 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-1
- Update to 2.0.1

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-2
- rebuild for PHP 7.1 new API version

* Fri Sep 09 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-1
- Update to 2.0.0 (php 7)
- open https://github.com/arnaud-lb/php-rdkafka/issues/71

* Fri Sep 09 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- Update to 1.0.0 (php 5)

* Tue Mar  8 2016 Remi Collet <remi@fedoraproject.org> - 0.9.1-2
- adapt for F24

* Mon Jan 11 2016 Remi Collet <remi@fedoraproject.org> - 0.9.1-1
- Update to 0.9.1 (beta)

* Sat Jan 09 2016 Remi Collet <remi@fedoraproject.org> - 0.9.0-1
- Update to 0.9.0 (beta)

* Thu May 14 2015 Remi Collet <remi@fedoraproject.org> - 0.0.2-1
- initial package, version 0.0.2 (alpha)
- open https://github.com/arnaud-lb/php-rdkafka/pull/5 - ZTS build
- open https://github.com/arnaud-lb/php-rdkafka/pull/4 - License
